==> haskell-hslua-module-text-1.1.0.1-161.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-8d0Q5JgMlDMHAj2YV0qW4Y
key:                  hslua-module-text-1.1.0.1-8d0Q5JgMlDMHAj2YV0qW4Y
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  da594038602e4fc6fa784c8c859f3902
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-8d0Q5JgMlDMHAj2YV0qW4Y
depends:
    base-4.18.2.1 hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-1.1.0.1-162-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-text
version:              1.1.0.1
visibility:           public
id:                   hslua-module-text-1.1.0.1-B62ljjYkscW3HooHzU83gW
key:                  hslua-module-text-1.1.0.1-B62ljjYkscW3HooHzU83gW
license:              MIT
copyright:            © 2017–2023 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  fa189c5e901908550d629eb2e0b21475
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.0.1-B62ljjYkscW3HooHzU83gW
depends:
    base-4.18.2.1 hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
